OiRA

Help

1. Priprema
2. Uključite
3. Prepoznavanje + procjena
   1. 1 Commercial manned guarding
   2. Ω Ostali izvori opasnosti, štetnosti i napora
      1. Ω.1 The entrance floor is often wet
   - Neodgovoren
   - Odgođen
   - Rizik ne postoji
   - Postoji rizik
4. Plan mjera
5. Završni dokumenti
6. Status 0%

U slučaju da na vašim mjestima rada identificirate opasnost, štetnost ili napor koji ovim alatom već nisu obuhvaćeni, možete ih proanalizirati ovdje.

Želite li sada ovom alatu dodati vlastite utvrđene rizike?

Važno:Kako biste izbjegli dupliciranje rizika, preporučamo vam da prvo prođete sve prethodne module, ako to još niste učinili.

Ako ne trebate dodavati rizike, odaberite 'Ne.

Prethodni Nastavite na Plan mjera

Scroll to top
Back

## other-risks.html

Više

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More